@@ -1,4 +1,5 @@
 skip_on_cran()
+skip_if_offline()
 
 skip_if_not_installed("httr")
 skip_if_not_installed("readxl")
@@ -11,8 +12,8 @@ skip_if_not_installed("rio")
 # csv -------------------------
 
 test_that("data_read", {
-  d <- data_read("https://stats.idre.ucla.edu/stat/data/binary.csv")
-  expect_equal(nrow(d), 400)
+  d <- data_read("https://raw.githubusercontent.com/easystats/circus/master/data/bootstrapped.csv")
+  expect_equal(dim(d), c(10000, 4))
 })
 
 
@@ -66,8 +67,23 @@ test_that("data_read", {
   d <- data_read(temp_file)
   expect_equal(sum(sapply(d, is.factor)), 15)
   expect_equal(sum(sapply(d, is.numeric)), 11)
-  expect_equal(levels(d$c172code), c("low level of education", "intermediate level of education", "high level of education"))
-  expect_equal(attr(d$n4pstu, "labels"), c(`spouse/partner` = 1, child = 2, sibling = 3, `daughter or son -in-law` = 4))
+  expect_equal(
+    levels(d$c172code),
+    c(
+      "low level of education",
+      "intermediate level of education",
+      "high level of education"
+    )
+  )
+  expect_equal(
+    attr(d$n4pstu, "labels"),
+    c(
+      `spouse/partner` = 1,
+      child = 2,
+      sibling = 3,
+      `daughter or son -in-law` = 4
+    )
+  )
 })
 
 unlink(temp_file)
