@@ -382,3 +382,11 @@ test_that("reverse works with data frames containing NAs (grouped data)", {
     )
   )
 })
+
+# select helpers ------------------------------
+test_that("reverse regex", {
+  expect_equal(
+    reverse(mtcars, select = "arb", regex = TRUE),
+    reverse(mtcars, select = "carb")
+  )
+})
